<template>
  <el-dialog
    width="60%"
    title="预留信息"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="order-stock-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="255"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      :selColValArr="paramSelArr"
      :selCol="paramSelCol"
      ref="orderStockTable"
    >
      <template #toolbar> </template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { fetchList } from '@/api/warehouse/joinstockorder'
import ttable from '@/views/common/ztt-table.vue'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    // 默认选中字段的值数组
    paramSelArr: {
      type: Array,
      default: () => {
        return []
      }
    },
    // 默认选中字段
    paramSelCol: {
      type: String
    }
  },
  data() {
    return {
      ajaxFun: fetchList,
      partsList: [],
      innerVisible: false,
      currentRow: null,
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '110',
            prop: 'customerOrderNo',
            label: '订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '110',
            prop: 'customerName',
            label: '客户名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '110',
            prop: 'coLineNo',
            label: '行号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '110',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '110',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'warehouseName',
            label: '仓库',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'locationNo',
            label: '库位号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'partBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '110',
            prop: 'reservedQuantity',
            label: '预留数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'number'
          },
          {
            minWidth: '110',
            prop: 'deliveryQuantity',
            label: '发货数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'number'
          },
          {
            minWidth: '100',
            prop: 'partUnit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      },
      addOrUpdateVisible: false,
      isUsed: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit('handleSelectionChange', this.multipleSelection)
      } else {
        this.$emit('listenToPartEvent', this.currentRow)
      }
      this.innerVisible = false
    },
    handleCurrentChange(val) {
      this.currentRow = val
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    // 获取数据列表
    getData() {
      if (this.$refs.orderStockTable !== undefined) {
        this.$refs.orderStockTable.getDataList()
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    },
    multiSelect() {
      this.$set(this.options, 'multiSelect', this.multiSelect)
    }
  }
}
</script>
<style>
.order-stock-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.order-stock-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.order-stock-dialog .el-dialog__body {
  padding: 5px 20px;
}

.order-stock-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.order-stock-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
